# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

check.pl - Simple checkbook handler

=head1 SYNOPSIS

    perl check.pl < {input-file}

=head1 DESCRIPTION

The I<check.pl> reads in checkbook data and prints statement showing
current balance in your account at each step of the way.

=head1 EXAMPLES

Sample run:

	perl check.pl <checks.txt
	01/01/01: Rent Payment         500.00  Total: 500.00
	01/01/01: Car Payment           86.29  Total: 586.29
	01/08/01: Grocery store         26.95  Total: 613.24
	01/15/01: Dog Groomer           19.95  Total: 633.19

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut

use strict;
use warnings;

my $total = 0;	# Current running total of all the checks

while (1) {
    # The line from the data file
    my $line = <STDIN>;

    # STDIN may be redirected, check for EOF
    if (not defined($line)) {
        last;
    }

    # Check for end of input
    chomp($line);

    if ($line eq "") {
        last;
    }

    # Split the data into it's fields
    my @check_info = split /\t/, $line;
    # $check_info[0] = Date
    # $check_info[1] = Description
    # $check_info[2] = Amount
    $total += $check_info[2];
    printf "%-8s: %-20s %6.2f  Total: %5.2f\n",
        $check_info[0], $check_info[1], $check_info[2], $total;
}
