# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

debug.pl - Run a CGI script in debug mode

=head1 SYNOPSIS

    perl debug.pl

=head1 DESCRIPTION

The I<debug.pl> asks you for a script name, then asks you for a set
of CGI parameters.  The parameters are encode using the same system
the web server uses for CGI program then the script is run in
debug mode (I<perl -d>).   

This allows you to debug CGI programs.

=head1 EXAMPLES

In this example we debug the program I<hello.pl>.   Our CGI program
gets on parameter who's name is I<TEST> and who's value is "value".

	perl debug.pl
	Script name: hello.pl
	Enter key=value
	(End with a blank line)
	> TEST=value
	> 
	Default die handler restored.
	
	Loading DB routines from perl5db.pl version 1.07
	Editor support available.
	
	Enter h or `h h' for help, or `man perldebug' for more help.
	
	main::(hello.pl:8):	print <<EOF
	main::(hello.pl:9):	Content: text/html
	DB<1>


=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

use CGI::Enurl;

# The information for the simulated CGI form
my %cgi_info = ();

# Get the name of the program to debug
print "Script name: ";
my $prog = <STDIN>;
chomp($prog);

# Prompt for data
print "Enter key=value\n";
print "(End with a blank line)\n";

# Get data 
while (1) {
    # Get a line from the user
    print "> ";
    my $line = <STDIN>;
    chomp($line);

    if ($line eq "") {
        last;
    }

    if ($line !~ /^([^=]*)\s*=\s*(.*)$/) {
        print "ERROR: Could not understand $line\n";
	next;
    }
    $cgi_info{$1} = $2;
}

# Encode the CGI data
my $url_info = enurl \%cgi_info;

# Setup a minimal CGI envronment
$ENV{QUERY_STRING} = $url_info;
$ENV{REQUEST_URI} = "$prog?$url_info";
$ENV{REQUEST_METHOD} = "GET";
# Execute the program in debug (and taint) mode
exec("perl -Td $prog");
