# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

bits1.pl - Test the inline set_bit and test_bit functions

=head1 SYNOPSIS

    perl bits1.pl

=head1 DESCRIPTION

The I<bits1.pl> tests out the inline bit functions.
These functions allow the user to set and test bits.

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut
use strict;
use warnings;

use Inline "C";

sub set_bit($$$);
sub test_bit($$);

set_bit(1,1,1);
set_bit(1,2,1);
if ((test_bit(1,1) != 1) ||
    (test_bit(1,2) != 1) ||
    (test_bit(1,3) != 0)) {
    die("Test #1 Failed");
}

set_bit(1,1,0);

if (test_bit(1,1) != 0) {
    die("Test #2 Failed");
}
print "Test passed\n";

__END__
__C__

#define X_SIZE 16
#define Y_SIZE 16
static unsigned char array[X_SIZE/8][Y_SIZE];

void set_bit(int x, int y, int value) {
    if (value != 0) 
	array[x/8][y] |= (0x80 >> (x % 8));
    else
	array[x/8][y] &= ~(0x80 >> (x % 8));
}

int test_bit(int x, int y) 
{
    return ((array[x/8][y] & (0x80 >> (x % 8))) != 0);
}
