# The lines from here to the =cut are part of Perl's
# internal documentation system.  If you want 
# view the documentation use the command:
#
#	pod2text <script>
#
=pod

=head1 NAME

bits2.pl - Test the inline set_bit and test_bit functions

=head1 SYNOPSIS

    perl bits2.pl

=head1 DESCRIPTION

The I<bits2.pl> tests out the inline bit functions.
These functions allow the user to set and test bits.

This function uses slightly different C/Perl interface than
the one used in I<bits1.pl>

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

Copyright 2002 Steve Oualline.
This program is distributed under the GPL.  

=cut

use strict;
use warnings;

use Inline "C";

sub set_bit($$$$);
sub test_bit($$$);

# The bit array we are using
my $bits = pack("C*", (0) x 32);

set_bit($bits, 1,1,1);
set_bit($bits, 1,2,1);
if ((test_bit($bits, 1,1) != 1) ||
    (test_bit($bits, 1,2) != 1) ||
    (test_bit($bits, 1,3) != 0)) {
    die("Test #1 Failed");
}

set_bit($bits, 1,1,0);

if (test_bit($bits, 1,1) != 0) {
    die("Test #2 Failed");
}
print "Tests passed\n";

__END__
__C__

#define X_SIZE 16
#define Y_SIZE 16

/* Size (in bytes) of the bit array */
#define SIZE_BYTES ((X_SIZE * Y_SIZE) / 8)



/* Index into an array which is actually a string */
static unsigned char *element(unsigned char *data, int x, int y)
{
    return (&data[y * X_SIZE + x]);
}

void set_bit(SV *bits, int x, int y, int value) {

    int len;	/* Length of the bit array */
    /* The bit array */
    unsigned char *array = SvPV(bits, len);

    if (len != SIZE_BYTES) {
	fprintf(stderr, "Bit array must be %d bytes long\n", SIZE_BYTES);
        croak("Can not continue");
    }

    if (value != 0) 
	*element(array, x/8, y) |= (0x80 >> (x % 8));
    else
	*element(array, x/8, y) &= ~(0x80 >> (x % 8));
}

int test_bit(SV *bits, int x, int y) 
{
    int len;	/* Length of the bit array */
    /* The bit array */
    unsigned char *array = SvPV(bits, len);

    if (len != SIZE_BYTES) {
	fprintf(stderr, "Bit array must be %d bytes long\n", SIZE_BYTES);
        croak("Can not continue");
    }

    return (
        ((*element(array, x/8, y)) & (0x80 >> (x % 8))) 
	!= 0);
}
