use strict;
use warnings;

=pod

=head1 NAME

new_disk.pl - Add a new disk to the collection

=head1 SYNOPSIS

    perl new_disk.pl <category> <description>

=head1 DESCRIPTION

The I<new_disk.pl> records disk information in the database.  It then 
displays the id number of the disk.

=head1 ARGUMENTS

=over 4

=item I<category>

A single letter representing the category of the disk.  Currently we
have defined the following categories:

=over 4

=item F

Floppy

=item C

CD-ROM

=item Z

Zip disk.

=back

=item I<description>

A description of the disk.   

=head1 FILES

=over 4

=item disks.db

The name of the database file.  The actual path to this file is 
controlled by the I<disks_config.pm> package.

=back

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 SEE ALSO

L<disk_report.pl> L<update_disk.pl>

=head1 COPYRIGHT

This program is distributed under the GPL.

=cut

use disks;
use disks_config;

if ($#ARGV != 1) {
    print STDERR "Usage is $0 <category> <description>\n";
    exit (8);
}

my $db = disks->new("disks.db", 0);

if (not defined($db)) {
    die("Could not open disks.db");
}
# Make category upper case
$ARGV[0] = uc($ARGV[0]);

if (not defined($category_to_name{$ARGV[0]})) {
    print STDERR "$ARGV[0] is not a legal category\n";
    print STDERR "Legal categories are:\n";
    foreach my $key (sort keys %category_to_name) {
        print STDERR "\t$key:$category_to_name{$key}\n";
    }
    exit (8);
}
my $id = $db->new_disk($ARGV[0], DESCRIPTION => $ARGV[1]);
if (not defined($id)) {
    print STDERR "ERROR: Could not create disk\n";
} else {
    print "Disk created.  ID=$id\n";
}
