use strict;
use warnings;

=pod

=head1 NAME

report.pl - Print a report about our disk library

=head1 SYNOPSIS

    perl report.pl

=head1 DESCRIPTION

The I<report.pl> prints a report containing all the disk information

=head1 FILES

=over 4

=item disks.db

The name of the database file.  The actual path to this file is 
controlled by the I<disks_config.pm> package.

=back

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 COPYRIGHT

This program is distributed under the GPL.

=cut

use disks;
use disks_config;

# The database to use
my $db = disks->new($db_file, 1);
if (not defined($db)) {
    die("Could not open $db_file");
}
# The data in the database
my @key_list = $db->get_keys();

# Print each as we find it
foreach my $cur_id (@key_list) {
    my $data = $db->get_disk($cur_id);
    printf "%3s: %-s\n", $cur_id, $data->{DESCRIPTION};
}
