=pod

=head1 NAME

update_disk.pl - Update an existing disk

=head1 SYNOPSIS

    perl update_disk.pl I<id> I<description>

=head1 DESCRIPTION

The I<update_disk.pl> updates the disk information for a given disk.

=head1 ARGUMENTS

=over 4

=item I<id>

The disk's identification.


=item I<description>

A description of the disk.   

=head1 FILES

=over 4

=item disks.db

The name of the database file.  The actual path to this file is 
controlled by the I<disks_config.pm> package.

=back

=head1 AUTHOR

Steve Oualline, E<lt>oualline@www.oualline.comE<gt>.

=head1 SEE ALSO

L<disk_report.pl> L<new_disk.pl>

=head1 COPYRIGHT

This program is distributed under the GPL.

=cut
use strict;
use warnings;

use disks;
use disks_config;

if ($#ARGV != 1) {
    print STDERR "Usage is $0 <id> <description>\n";
    exit (8);
}

my $db = disks->new("disks.db", 0);

if (not defined($db)) {
    die("Could not open disks.db");
}

if (not defined ($db->update_disk($ARGV[0], DESCRIPTION => $ARGV[1]))) {
    print STDERR "Error: Could not find the disk $ARGV[0]\n";
} else {
    print "Disk updated\n";
}
