=pod

=head1 NAME

table.pl - Print out tables nicely formated

=head1 SYNOPSIS

    table.pl <file> [<file> ....]  

=head1 DESCRIPTION

The I<table.pl> examines the input files which are assumed to contain
data in columns and prints them nicely.  In other words, it makes
the tables look nice.

=cut
use strict;
use warnings;


# The input as lines, then as columns
my @lines = ();

#
# Grab input, break apart into fields
#
while (<>) {
    chomp($_);
    my @words = split /\s+/, $_;
    push (@lines, [@words]);
}

#
# Find out how many fields there are
#
my $n_fields = 0;

foreach my $cur_line (@lines) {
    if ($#$cur_line > $n_fields) {
	$n_fields = $#$cur_line;
    }
}

#
# Find the size of each field.
#
my @field_size = ();
for (my $cur_field = 0;
	$cur_field <= $n_fields;
	$cur_field++) {

    $field_size[$cur_field] = 0;
    foreach my $cur_line (@lines) {
	if (not defined($cur_line->[$cur_field])) {
	    next;
	}
	if (length($cur_line->[$cur_field]) > 
		$field_size[$cur_field]) {
	    $field_size[$cur_field] = 
		length($cur_line->[$cur_field]);
	}
    }
}

#
# Build the printing format
#
my $format = "";
foreach my $cur_field (@field_size) {
    if ($format ne "") {
	$format .= " ";
    }
    $format .= "%-${cur_field}s";
}
$format .= "\n";
	
#
# Print
#
foreach my $cur_line (@lines) {
    printf $format, @$cur_line;
}

